TLoginTemplate class
Template for the login page layout. Provides a reusable structure for a login page with responsiveness.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TLoginTemplate
Constructors
- TLoginTemplate({Key? key, required Widget child, Widget? loginAnimation, Color? animationBackgroundColor, EdgeInsets? padding, double? margin, String imageAsset = 'assets/loader.gif'})
-
const
Properties
- animationBackgroundColor → Color?
-
Background color for the login animation, defaults to TColors().primary.
final
- child → Widget
-
The widget to be displayed inside the login template (e.g., forms, buttons).
final
-
Text to display in the footer, defaults to "Powered by Coding with T."
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageAsset → String
-
Asset image for the login animation, defaults to 'assets/loader.gif'.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loginAnimation → Widget?
-
Custom login animation (e.g., image or widget).
final
- margin → double?
-
Margin for the content area, can be customized.
final
- padding → EdgeInsets?
-
Padding for the content area, can be customized.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited